pub async fn find_by_user(
user_id: Uuid,
pool: &SharedPool,
) -> Result<GuidedTourDto, ServiceError>Expand description
Get guided tour info for a user
Errors
If the connection to the database could not be established.
pub async fn find_by_user(
user_id: Uuid,
pool: &SharedPool,
) -> Result<GuidedTourDto, ServiceError>Get guided tour info for a user
If the connection to the database could not be established.